/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include <dawn/dawn.h>
#include "card.h"

/**
 * Returns true if the player is still alive and in the current game/
 * Defined as: Not out, not folded.
 * 
 * @param player Player to check
 * @returns True if alive/in teh current game.
 */
bool pokerPlayerIsAlive(pokerplayer_t *player);

/**
 * Returns true if the player provided is human or not.
 * 
 * @param poker Poker game instance.
 * @param player Player instance.
 * @returns True if the player is human.
 */
bool pokerPlayerIsHuman(poker_t *poker, pokerplayer_t *player);

/**
 * Deal a card to a player.
 * 
 * @param poker Poker game instance.
 * @param player Poker player to deal to.
 */
void pokerPlayerDeal(poker_t *poker, pokerplayer_t *player);

/**
 * Deal card(s) to every active player.
 * 
 * @param poker Poker game instance.
 * @param count Count of cards to deal.
 */
void pokerPlayerDealAll(poker_t *poker, uint8_t count);